searchData={"content_type":"text/markdown","items":[{"doc":"Directly map environment variables into the application\nconfiguration at runtime including type conversion and\ncomplex type bundling.\n\n# Types supported\n\n* S - String\n* A - Atom\n* I - Integer\n* B - boolean (true or TRUE is true all else is false)\n* F - Float\n* M - Module name\n* C - charlist\n* J - JSON encoded string\n* G - Erlang term\n* T - Base64 encoded Erlang term\n* PEM - PEM string, see note below\n\nType specifiers are required suffixes, two underscores and the\ntype, e.g.:\n\n```\nje__my_app__some_string__S=\"a string value\"\n```\n\n#","ref":"Jetenv.html","title":"Jetenv","type":"module"},{"doc":"PEM strings are decoded using :public_key, however the usual\nconsumers of the results (private key or cert) expect\ndifferent things than what :public_key returns. The PEM\nhandler provides values appropriate for use in `ssl_opts`\n`cacert` and `key`.\n\n#","ref":"Jetenv.html#module-pem-handling","title":"PEM handling - Jetenv","type":"module"},{"doc":"There is a special case for representing a module name\nin the key string. This often occurs for configuring\necto Repos.\n\nA module will be detected by starting with `Elixir`.\nUnderscores will be effectively translated to dots.\n\nExample:\n\n```\nje__my_app__Elixir_MyApp_Repo__database__S=mydb\n```","ref":"Jetenv.html#module-modules-in-keys","title":"Modules in keys - Jetenv","type":"module"},{"doc":"Accepts a map (such as from `System.get_env/0`)\nand generates a config tree.\n\nSee `t:run_options/0`","ref":"Jetenv.html#load/2","title":"Jetenv.load/2","type":"function"},{"doc":"Same as `load_env/1` except does not filter out\nconfig against loaded applications.\n\nSee `t:run_options/0`","ref":"Jetenv.html#load_all_env/1","title":"Jetenv.load_all_env/1","type":"function"},{"doc":"Processes values from the environment into a nested\nKeyword list suitable for use in runtime.exs or\nas confg to `Application.put_all_env/2`.\n\nThis variant will filter out non-loaded applications.\n\nPrefix can be specified to override environment.\n\nSee `t:run_options/0`","ref":"Jetenv.html#load_env/1","title":"Jetenv.load_env/1","type":"function"},{"doc":"The default is `je` but can be overridden by setting the\nenvironment variable `jetenv_prefix`. This function\nreturns the prefix in effect.\n\nIf options are not provided to load functions, this\nwill provide the default.","ref":"Jetenv.html#prefix_env/0","title":"Jetenv.prefix_env/0","type":"function"},{"doc":"Common run options are:\n\n* prefix: String.t - the string a name starts with for discovery","ref":"Jetenv.html#t:run_options/0","title":"Jetenv.run_options/0","type":"type"},{"doc":"Key and value decoding.","ref":"Jetenv.Decode.html","title":"Jetenv.Decode","type":"module"},{"doc":"Convert environment style key/values into a configuration.\n\nKeys are expected to be keyword path strings separated\nby double underscores with a trailing type specifier.\n\nDerives a deep Keyword path from the key provided.\nPerforms type conversion of value based on type suffix.\n\nSee `Jetenv` for type information.","ref":"Jetenv.Decode.html#decode/2","title":"Jetenv.Decode.decode/2","type":"function"},{"doc":"Generate environment from config KWL","ref":"Jetenv.Encode.html","title":"Jetenv.Encode","type":"module"},{"doc":"Encode input from Application.get_all_env. Provide `app` to\nadd app key to tree, `prefix` for name prefix.","ref":"Jetenv.Encode.html#from_config/3","title":"Jetenv.Encode.from_config/3","type":"function"},{"doc":"generate output suitable for input to:\n\n* --docker docker api json\n* --js javascript/json key/val dictionary\n* --sh shell environment variable eval-able\n* no option, plain json\n\npositional arguments, otp application names to generate\n\ncustomize prefix (default is 'je') with --prefix\n\njson environment suitable for docker api","ref":"Mix.Tasks.Jetenv.Generate.html","title":"mix jetenv.generate","type":"task"},{"doc":"","ref":"Mix.Tasks.Jetenv.Generate.html#wrapping/2","title":"Mix.Tasks.Jetenv.Generate.wrapping/2","type":"function"},{"doc":"# Jetenv\n\nFull Application configuration from only the environment by using\na predictable and direct name translation into config node plus\ntype specification and bundled/armored encoding for complex types.","ref":"readme.html","title":"Jetenv","type":"extras"},{"doc":"Given that Application configuration is a tree data structure comprised of \nKeyword lists, addressing any point in the KW hierarchy can be expressed as\na path. If the implied root of the structure is the application controller\nand the next nodes are the applications (otp_app atoms), then a path can\nbe built to locate/set configuration at any point.","ref":"readme.html#background","title":"Background - Jetenv","type":"extras"},{"doc":"The POSIX standards place limits on variable names, but none on values.\nModern systems provide an ARG_MAX of about 4MiB, so considerable data\nspace is available.\n\nPOSIX programs use upper case variable names, lower case is reserved for\napplications. The only special character is the underscore `_`.","ref":"readme.html#environment-design-limits","title":"Environment Design limits - Jetenv","type":"extras"},{"doc":"* Path segments are separated by a double underscore `__`\n* Variables use a common prefix (default is `je`), allows automatic configuration\n* A required type suffix allows automatic interpolation\n\nExample:\n\n```\nje__my_app__some_thing__S=\"A string value\"\n\n```","ref":"readme.html#variable-name-construction","title":"Variable name construction - Jetenv","type":"extras"},{"doc":"See `Jetenv`","ref":"readme.html#types-supported","title":"Types supported - Jetenv","type":"extras"},{"doc":"Included is a mix task, `mix jetenv.generate` that can emit documents that\ncan be used to perform environment set up for:\n\n* docker api\n* javascript (ts/CDK)\n* shell\n\nSee `mix help jetenv.generate`\n\nTo see an example, run `mix jetenv.generate elixir`.\n\n#","ref":"readme.html#generator","title":"Generator - Jetenv","type":"extras"},{"doc":"A docker `--env-file` is not directly supported because that format\ndoesn't support multi-line values. The format is neither shell nor\njson. It has no escaping mechanism.\n\nFor deployment into any orchestration, this is not usually a problem. For\nlocal docker development it is a hassle. One option it to generate a shell format\nfile and source it within the container prior to starting elixir. The other\napproach is to use the Docker API (which is JSON) to create and then start\na container.","ref":"readme.html#generation-limitations","title":"Generation Limitations - Jetenv","type":"extras"},{"doc":"In your config/runtime.exs add:\n\n```\nJetenv.load_env()\n```\n\nThis will load from the environment using the default prefix `je`.","ref":"readme.html#use","title":"Use - Jetenv","type":"extras"},{"doc":"The `Jetenv.load_env()/0` function will filter available configuration\nto include only loaded applications. Use `Jetenv.load_all_env()/0`\nto bypass that filter. If Application does not know about\nan otp_app in that case, you will see a warning:\n\n```\nYou have configured application :app in your configuration file,\nbut the application is not available.\n\nThis usually means one of:\n\n  1. You have not added the application as a dependency in a mix.exs file.\n\n  2. You are configuring an application that does not really exist.\n\nPlease ensure :app exists or remove the configuration.\n```\n\nThis message is harmless.","ref":"readme.html#loaded-applications","title":"Loaded applications - Jetenv","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `jetenv` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:jetenv, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Jetenv","type":"extras"}]}